@@ -31,7 +31,9 @@ class UserenaLocaleMiddleware(MiddlewareMixin):
 
                 if profile:
                     try:
-                        lang = getattr(profile, userena_settings.USERENA_LANGUAGE_FIELD)
+                        lang = getattr(
+                            profile, userena_settings.USERENA_LANGUAGE_FIELD
+                        )
                         translation.activate(lang)
                         request.LANGUAGE_CODE = translation.get_language()
                     except AttributeError:
